from os import sep
import pandas as pd
import numpy as np
import warnings

# warnings.filterwarnings("ignore")
NAN = np.nan


def get_mims_matrix_hour(df_minute):
    ymd_list = []
    hour_list = []
    tz_list = []
    mims_sample_num_list = []
    mims_invalid_sample_num_list = []
    mims_sum_list = []

    ymd = list(df_minute.YEAR_MONTH_DAY.unique())[0]

    for hour in range(24):
        df_subset = df_minute[df_minute.HOUR == str(hour)]
        tz = list(df_subset.TIMEZONE.unique())[0]
        mims_sample_num_hour = df_subset.MIMS_SAMPLE_NUM.sum()
        if mims_sample_num_hour == 0:
            mims_invalid_sample_num_hour = NAN
            mims_sum_hour = NAN
        else:
            mims_invalid_sample_num_hour = df_subset.MIMS_INVALID_SAMPLE_NUM.sum()
            mims_sum_hour = df_subset.MIMS_SUM.sum()

        ymd_list.append(ymd)
        hour_list.append(hour)
        tz_list.append(tz)
        mims_sample_num_list.append(mims_sample_num_hour)
        mims_invalid_sample_num_list.append(mims_invalid_sample_num_hour)
        mims_sum_list.append(mims_sum_hour)

    df_hour = pd.DataFrame(
        {"YEAR_MONTH_DAY": ymd_list, "HOUR": hour_list, "TIMEZONE": tz_list, "MIMS_SAMPLE_NUM": mims_sample_num_list,
         "MIMS_INVALID_SAMPLE_NUM": mims_invalid_sample_num_list, "MIMS_SUM": mims_sum_list})

    return df_hour


if __name__ == "__main__":
    df_minute = pd.read_csv(
        r"C:\Users\Jixin\Downloads\watch_accelerometer_decompose_minute_2021-02-04.csv")
    df_hour = get_mims_matrix_hour(df_minute)
    print(df_hour)
    df_hour.to_csv(r"C:\Users\Jixin\Downloads\watch_accelerometer_decompose_hour_2021-02-04.csv")



import csv
import sys
import os
from glob import glob
import pandas as pd
from os import sep

# Import the rpy2 package to run R commands and then import MIMSunit package using that
from rpy2.robjects.packages import importr
from rpy2.robjects import pandas2ri
from rpy2.robjects.conversion import localconverter
import rpy2.robjects as ro
from rpy2.robjects import FloatVector
# pandas2ri.activate()


mims_unit = importr('MIMSunit')
get_mims = mims_unit.mims_unit

G_VAL = 9.8
DYNAMIC_RANGE = [-8, 8]


def csvToMIMS(hour_folder_path, date, hour):
    in_path = sorted(glob(os.path.join(hour_folder_path, '020000000000-AccelerationCalibrated.*.sensor.csv')))[0]

    # Read the csv file and create a data frame
    rows = []
    with open(in_path) as resp_csv:
        csv_reader = csv.reader(resp_csv, delimiter=",")
        for row in csv_reader:
            if len(row) > 3:
                rows.append(row)
            else:
                print("warning: error line skipped    {}".format(in_path))
    raw_data_csv = pd.DataFrame(rows[1:])
    raw_data_csv.columns = rows[0]

    raw_data_csv['X_ACCELATION_METERS_PER_SECOND_SQUARED'] = [float(x) / G_VAL for x in raw_data_csv['X_ACCELATION_METERS_PER_SECOND_SQUARED']]
    raw_data_csv['Y_ACCELATION_METERS_PER_SECOND_SQUARED'] = [float(x) / G_VAL for x in raw_data_csv['Y_ACCELATION_METERS_PER_SECOND_SQUARED']]
    raw_data_csv['Z_ACCELATION_METERS_PER_SECOND_SQUARED'] = [float(x) / G_VAL for x in raw_data_csv['Z_ACCELATION_METERS_PER_SECOND_SQUARED']]

    # Convert date to datetime object
    raw_data_csv['HEADER_TIME_STAMP'] = pd.to_datetime(raw_data_csv['HEADER_TIME_STAMP'], format='%Y-%m-%d %H:%M:%S.%f')

    # Convert to R dataframe needed for MIMSunit

    with localconverter(ro.default_converter + pandas2ri.converter):
        r_from_pd_df = ro.conversion.py2rpy(raw_data_csv)

    # r_from_pd_df = ro.conversion.py2rpy(raw_data_csv)

    # Convert dynamic range into R list
    r_g_range = FloatVector(DYNAMIC_RANGE)

    mims_df = get_mims(r_from_pd_df, dynamic_range=r_g_range, epoch='1 sec')


    with localconverter(ro.default_converter + pandas2ri.converter):
        pd_from_r_df = ro.conversion.rpy2py(mims_df)

    # pd_from_r_df = ro.conversion.rpy2py(mims_df)

    pd_from_r_df['HEADER_TIME_STAMP'] = pd_from_r_df['HEADER_TIME_STAMP'].dt.strftime('%Y-%m-%d %H:%M:%S')

    # pd_from_r_df['HEADER_TIME_STAMP'] = pd_from_r_df['HEADER_TIME_STAMP'].apply(lambda x: x.replace(microsecond=0))
    out_path = os.path.dirname(in_path) + sep + "mims_" + date + "_" + hour + ".csv"
    pd_from_r_df.to_csv(out_path, index=False)
    return pd_from_r_df

if __name__ == "__main__":
    in_path = sys.argv[1]
    csvToMIMS(in_path)


from os import sep
import pandas as pd
import warnings

warnings.filterwarnings("ignore")


def parse_raw_df(df_hour_raw, time_zone):
    columns_names = ["LOG_TIME", "LOG_TYPE", "PARTICIPANT_ID", "FILE_NAME", "LOG"]
    if df_hour_raw.shape[0] > 0:
        df_hour_raw.columns = columns_names
        df_hour_raw.fillna('-1', inplace=True)
        df_hour_raw = df_hour_raw[~df_hour_raw['LOG'].str.contains('TIME_TICK')]
        if (df_hour_raw.LOG == 'android.intent.action.SCREEN_ON').shape[0] > 0:
            df_hour_raw.loc[(df_hour_raw.LOG == 'android.intent.action.SCREEN_ON'), 'PHONE_EVENT'] = 'PHONE_SCREEN_ON'
        if (df_hour_raw.LOG == 'android.intent.action.SCREEN_OFF').shape[0] > 0:
            df_hour_raw.loc[(df_hour_raw.LOG == 'android.intent.action.SCREEN_OFF'), 'PHONE_EVENT'] = 'PHONE_SCREEN_OFF'
        if (df_hour_raw.LOG == 'android.intent.action.USER_PRESENT').shape[0] > 0:
            df_hour_raw.loc[(df_hour_raw.LOG == 'android.intent.action.USER_PRESENT'), 'PHONE_EVENT'] = 'PHONE_UNLOCKED'
        if (df_hour_raw.LOG == 'android.intent.action.BOOT_COMPLETED').shape[0] > 0:
            df_hour_raw.loc[(df_hour_raw.LOG == 'android.intent.action.BOOT_COMPLETED'), 'PHONE_EVENT'] = 'PHONE_BOOTED'
        if (df_hour_raw.LOG == 'android.intent.action.ACTION_SHUTDOWN').shape[0] > 0:
            df_hour_raw.loc[(df_hour_raw.LOG == 'android.intent.action.ACTION_SHUTDOWN'), 'PHONE_EVENT'] = 'PHONE_SHUTDOWN'
        if (df_hour_raw.LOG == 'android.intent.action.CONFIGURATION_CHANGED').shape[0] > 0:
            df_hour_raw.loc[(df_hour_raw.LOG == 'android.intent.action.CONFIGURATION_CHANGED'), 'PHONE_EVENT'] = \
            'PHONE_CONFIGRATION_CHANGED'
        if (df_hour_raw.LOG == 'android.intent.action.BATTERY_CHANGED').shape[0] > 0:
            df_hour_raw.loc[(df_hour_raw.LOG == 'android.intent.action.BATTERY_CHANGED'), 'PHONE_EVENT'] = \
            'PHONE_BATTERY_CHANGED'
        if (df_hour_raw.LOG == 'android.intent.action.ACTION_AIRPLANE_MODE_CHANGED').shape[0] > 0:
            df_hour_raw.loc[(df_hour_raw.LOG == 'android.intent.action.ACTION_AIRPLANE_MODE_CHANGED'), 'PHONE_EVENT'] = \
            'PHONE_AIRPLANE_MODE_CHANGED'
        if (df_hour_raw.LOG == 'android.intent.action.ACTION_USER_UNLOCKED').shape[0] > 0:
            df_hour_raw.loc[(df_hour_raw.LOG == 'android.intent.action.ACTION_USER_UNLOCKED'), 'PHONE_EVENT'] = \
            'PHONE_UNLOCKED'
        if (df_hour_raw.LOG == 'android.intent.action.HEADSET_PLUG').shape[0] > 0:
            df_hour_raw.loc[(df_hour_raw.LOG == 'android.intent.action.HEADSET_PLUG'), 'PHONE_EVENT'] = \
            'PHONE_HEADSET_PLUGGED'
        if (df_hour_raw.LOG == 'android.intent.action.ACTION_POWER_CONNECTED').shape[0] > 0:
            df_hour_raw.loc[(df_hour_raw.LOG == 'android.intent.action.ACTION_POWER_CONNECTED'), 'PHONE_EVENT'] = \
            'PHONE_POWER_CONNECTED'
        if (df_hour_raw.LOG == 'android.intent.action.ACTION_POWER_DISCONNECTED').shape[0] > 0:
            df_hour_raw.loc[(df_hour_raw.LOG == 'android.intent.action.ACTION_POWER_DISCONNECTED'), 'PHONE_EVENT'] = \
            'PHONE_POWER_DISCONNECTED'
        df_hour_raw = df_hour_raw.drop('LOG_TYPE', 1)
        df_hour_raw = df_hour_raw.drop('FILE_NAME', 1)
        df_hour_raw = df_hour_raw.drop('LOG', 1)
        if 'PHONE_EVENT' in df_hour_raw.columns:
            df_hour_raw = df_hour_raw[['PARTICIPANT_ID', 'LOG_TIME', 'PHONE_EVENT']]
        else:
            df_hour_raw = df_hour_raw[['PARTICIPANT_ID', 'LOG_TIME']]

    return df_hour_raw


if __name__ == "__main__":
    target_file = "Battery.020000000000-Battery.2020-06-02-02-00-25-506-M0400.event.csv"
    hour_folder_path = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT\aditya4_internal@timestudy_com\data-watch\2020-06-02\02-EDT"
    target_file_path = hour_folder_path + sep + target_file
    output_file_path = r"C:\Users\jixin\Desktop\temp\temp_file.csv"
    p_id = "aditya4_internal@timestudy_com"

    df_hour_raw = pd.read_csv(target_file_path)
    print(df_hour_raw)
    df_hour_parsed = parse_raw_df(df_hour_raw)
    df_hour_parsed.to_csv(output_file_path, index=False)



from . import main
from . import parse
from . import bafToCSV
from . import csvToMIMS
from . import dataframe_to_MIMS
from . import baf_to_dataframe
from . import MIMS_minute
from . import MIMS_hour
from . import AUC_minute
from . import AUC_hour


import gzip
import os
import shutil
import subprocess
from os import sep, getcwd

JAR = getcwd() + sep + "preprocess_scripts" + sep + "utils" + sep + "binarytocsv.jar"


def bafToCsv(file):
    tmpDir = os.path.dirname(file)
    tmpFi = os.path.basename(file)
    tmpFii = tmpFi.replace("AndroidWearWatch-AccelerationCalibrated-NA.", "")
    tmpFull = os.path.join(tmpDir, tmpFii)

    outfilePath = tmpFull[:-4] + '.csv.gz'

    if os.path.exists(outfilePath):
        print(outfilePath + " exists. Skipping binary to csv conversion for this file.")
        return outfilePath
    outPath = os.path.dirname(file)
    try:
        subprocess.call(['java', '-jar', JAR, file, outPath])
    except:
        print('Issue with converting baf file to csv - ' + file)
        return None

    try:
        with open(outfilePath[:-3], 'rb') as f_in:
            with gzip.open(outfilePath, 'wb') as f_out:
                shutil.copyfileobj(f_in, f_out)
    except:
        print('Issue compressing the csv file - ' + outfilePath[:-3])
        return None

    return outfilePath

if __name__ == "__main__":
    file = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT\aditya4_internal@timestudy_com\data-watch\2020-06-08\10-EDT\AndroidWearWatch-AccelerationCalibrated-NA.020000000000-AccelerationCalibrated.2020-06-08-10-19-57-375-M0400.sensor.baf"
    # outfilePath = r"C:\Users\jixin\Desktop\temp"
    bafToCsv(file)



from os import sep
import pandas as pd
import numpy as np
import warnings

# warnings.filterwarnings("ignore")
NAN = np.nan


def get_auc_matrix_hour(df_minute):
    ymd_list = []
    hour_list = []
    tz_list = []
    auc_sample_num_list = []
    auc_x_list = []
    auc_y_list = []
    auc_z_list = []

    ymd = list(df_minute.YEAR_MONTH_DAY.unique())[0]

    for hour in range(24):
        df_subset = df_minute[df_minute.HOUR == str(hour)]
        tz = list(df_subset.TIMEZONE.unique())[0]

        auc_sample_num_hour = df_subset.SAMPLE_COUNT.sum()
        if auc_sample_num_hour == 0:
            auc_x_hour = NAN
            auc_y_hour = NAN
            auc_z_hour = NAN
        else:
            auc_x_hour = df_subset.AUC_X.sum()
            auc_y_hour = df_subset.AUC_Y.sum()
            auc_z_hour = df_subset.AUC_Z.sum()

        ymd_list.append(ymd)
        hour_list.append(hour)
        tz_list.append(tz)
        auc_sample_num_list.append(auc_sample_num_hour)
        auc_x_list.append(auc_x_hour)
        auc_y_list.append(auc_y_hour)
        auc_z_list.append(auc_z_hour)

    df_hour = pd.DataFrame(
        {"YEAR_MONTH_DAY": ymd_list, "HOUR": hour_list, "TIMEZONE": tz_list, "SAMPLE_COUNT": auc_sample_num_list,
         "AUC_X": auc_x_list, "AUC_Y": auc_y_list, "AUC_Z": auc_z_list})

    return df_hour


if __name__ == "__main__":
    df_minute = pd.read_csv(
        r"C:\Users\Jixin\Downloads\auc_minute.csv")
    print(df_minute.TIMEZONE)
    df_hour = get_auc_matrix_hour(df_minute)
    print(df_hour)
    # df_hour.to_csv(r"C:\Users\Jixin\Downloads\watch_accelerometer_decompose_hour_2021-02-04.csv")



suffix = "@timestudy_com"


def filterParticipantList(p_id_list):
    filtered_list = []

    # check suffix
    for p_id in p_id_list:
        if not p_id.endswith(suffix):
            filtered_list.append(p_id)
        else:
            print(
                "warning: participant ID  ( {} ) doesn't need suffix \"{}\". The program will automatically strip the "
                "suffix for each participant ID.".format(
                    p_id, suffix))
            filtered_list.append(p_id.replace(suffix, ''))

    # remove duplicates
    filtered_list = list(dict.fromkeys(filtered_list))
    return filtered_list


def cleanLine(line):
    line = line.strip('\n')
    return line


def parse_participants(participant_text_file_path):
    p_id_list = []
    with open(participant_text_file_path) as fp:
        Lines = fp.readlines()
        for line in Lines:
            cleaned_line = cleanLine(line)
            if len(cleaned_line) != 0:
                p_id_list.append(cleaned_line)

    p_id_list_filtered = filterParticipantList(p_id_list)
    # add suffix
    p_id_list_with_suffix = [x + suffix for x in p_id_list_filtered]
    print("\n> Entered Participant IDs ({} participants in total) :".format(len(p_id_list_with_suffix)))
    for i in range(len(p_id_list_with_suffix)):
        print(" {}.  {}".format(i + 1, p_id_list_with_suffix[i]))
    print("\n")
    return p_id_list_with_suffix


if __name__ == "__main__":
    participant_text_file_path = r"C:\Users\jixin\Documents\GitHub\microt_preprocessing\resource\sample_file" \
                                 r"\participants_sample "
    p_id_list = parse_participants(participant_text_file_path)



import os
import shutil
from os import path, makedirs

from ...utils.validate_dates import *
from ...utils.validate_hours import validate_hours
from ...utils.get_time_zone import *
from .parse import *
import warnings

warnings.filterwarnings("ignore")

area = "data"
device = "phone"
file_shortname = "stepCount"

# since the battery file name is mixed with irregular numbers, file name matching is needed.
name_pattern = "StepCounterService"


def reg_exp_matching(hour_folder_path, name_pattern):
    file_list = listdir(hour_folder_path)
    matched_name = ""
    for file_str in file_list:
        if file_str.startswith(name_pattern):
            matched_name = file_str
            break
    return matched_name


def pre_process(microT_root_path, intermediate_file_save_path, p_id, decrypt_password, date):
    participant_folder_path = microT_root_path
    area_folder_path = participant_folder_path + sep + area
    hours_with_target_file_list = {}  # included in participant stats report
    if path.exists(area_folder_path):
        date_folder_path = area_folder_path + sep + date
        if path.exists(date_folder_path):
            file_save_date_path = intermediate_file_save_path + sep + "intermediate_file" + sep + p_id + sep + date
            if not path.exists(file_save_date_path):
                makedirs(file_save_date_path)
            day_file_name = device + "_" + file_shortname + "_clean_" + date + ".csv"
            day_file_save_path = file_save_date_path + sep + day_file_name
            if not path.exists(day_file_save_path):
                df_participant = pd.DataFrame()
                # time zone
                # time_zone = get_time_zone(date_folder_path)

                # check hourly folder
                validated_hour_list, HAVE_ALL_HOURS = validate_hours(date_folder_path)
                if len(validated_hour_list) == 0:
                    print("Cannot find hour folder in {} data".format(date))

                # iterate through hour folders
                hours_with_target_file = len(validated_hour_list)  # included in participant stats report
                for hour in validated_hour_list:
                    hour_folder_path = date_folder_path + sep + hour

                    # step 2.1: read target hourly file
                    target_file_matched = reg_exp_matching(hour_folder_path, name_pattern)
                    if len(target_file_matched) > 0:
                        target_file_path = hour_folder_path + sep + target_file_matched
                        try:
                            df_hour_raw = pd.read_csv(target_file_path, header=None)
                        except:
                            # print("Empty csv file", target_file_path)
                            continue
                    else:
                        hours_with_target_file -= 1
                        continue

                    # step 2.2: parse target hourly file
                    if df_hour_raw.shape[0] != 0:
                        # time zone
                        time_zone = get_time_zone(hour_folder_path)
                        df_hour_parsed = parse_raw_df(df_hour_raw, time_zone)
                        # step 2.4: concatenate hourly file in day level
                        if df_hour_parsed.shape[0] != 0:
                            df_participant = pd.concat([df_participant, df_hour_parsed])
                hours_with_target_file_list[date] = hours_with_target_file
                if hours_with_target_file != 0:
                    # step 3:  write out day file for participant
                    df_participant.to_csv(day_file_save_path, index=False)


if __name__ == "__main__":
    microT_root_path = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT"
    intermediate_file_save_path = r"C:\Users\jixin\Desktop\temp"
    p_id_list = ["aditya4_internal@timestudy_com"]
    date_start = "2020-01-01"
    date_end = "2020-07-01"

    pre_process(microT_root_path, intermediate_file_save_path, p_id_list, date_start, date_end)



from os import sep
import pandas as pd
import numpy as np
import warnings

# warnings.filterwarnings("ignore")
NAN = np.nan
colnames = ["YEAR_MONTH_DAY", "HOUR", "MINUTE", "TIMEZONE", "MIMS_SAMPLE_NUM", "MIMS_INVALID_SAMPLE_NUM", "MIMS_SUM"]


def get_mims_matrix_minute(df_mims_day):
    if df_mims_day.shape[0] == 0:
        return None

    # transform df_mims_day
    ymd_list = []
    hour_list = []
    minute_list = []
    tz_list = []
    for time_str in df_mims_day["HEADER_TIME_STAMP"]:
        hour_min_millisecond = time_str.split(" ")[1]
        hour_min_second = hour_min_millisecond.split(".")[0]
        hour_min_second_components = hour_min_second.split(":")

        hour_list.append(int(hour_min_second_components[0]))
        minute_list.append(int(hour_min_second_components[1]))
        ymd_list.append(time_str.split(" ")[0])
        tz_list.append(time_str.split(" ")[2])

    # skip for days with multiple timezone
    tz_set = set(tz_list)
    tz_set_clean = set([x.split("_")[0] for x in tz_set])
    tz_num = len(tz_set_clean)

    # iterate through all minutes in a day and find matched time in df_mims_day
    idx = 0
    idx_max = df_mims_day.shape[0]
    hour_min_dict = dict()
    for hour in range(24):
        for min in range(60):
            hour_min = str(hour) + "_" + str(min)

            # temporary measure for days with multiple timezones
            if tz_num > 1:
                hour_min_dict[hour_min] = {"MIMS_SAMPLE_NUM": NAN, "MIMS_INVALID_SAMPLE_NUM": NAN, "MIMS_SUM": NAN}
                continue

            if idx < idx_max:
                hour_min_in_df = str(hour_list[idx]) + "_" + str(minute_list[idx])

            flag = 0
            while hour_min == hour_min_in_df:
                flag = 1

                mims_value_sec = df_mims_day["MIMS_UNIT"][idx]
                invalid_sample_num = 0
                if mims_value_sec < 0:  # convert -0.01 to 0
                    mims_value_sec = 0
                    invalid_sample_num = 1

                if hour_min in hour_min_dict:
                    hour_min_dict[hour_min]["MIMS_SAMPLE_NUM"] += 1
                    hour_min_dict[hour_min]["MIMS_SUM"] += mims_value_sec
                    hour_min_dict[hour_min]["MIMS_INVALID_SAMPLE_NUM"] += invalid_sample_num
                else:
                    hour_min_dict[hour_min] = {"MIMS_SAMPLE_NUM": 1, "MIMS_INVALID_SAMPLE_NUM": invalid_sample_num,
                                               "MIMS_SUM": mims_value_sec}

                idx += 1
                if idx == idx_max:
                    break
                hour_min_in_df = str(hour_list[idx]) + "_" + str(minute_list[idx])

            if flag == 0:
                hour_min_dict[hour_min] = {"MIMS_SAMPLE_NUM": 0, "MIMS_INVALID_SAMPLE_NUM": NAN, "MIMS_SUM": NAN}

    YMD = list(set(ymd_list))[0]
    tz = list(tz_set_clean)[0]
    rows = []
    for hour_min in hour_min_dict:
        row = [YMD, hour_min.split("_")[0], hour_min.split("_")[1], tz, hour_min_dict[hour_min]["MIMS_SAMPLE_NUM"],
               hour_min_dict[hour_min]["MIMS_INVALID_SAMPLE_NUM"], hour_min_dict[hour_min]["MIMS_SUM"]]
        rows.append(row)

    df_minute = pd.DataFrame(rows, columns=colnames)

    return df_minute


if __name__ == "__main__":
    df_mims_day = pd.read_csv(
        r"D:\data\TIME\intermediate_sample\idealistsustainerexpansive@timestudy_com\2021-11-07\watch_accelerometer_mims_clean_2021-11-07.csv")
    df_minute = get_mims_matrix_minute(df_mims_day)
    print(df_minute)



# import os
from os import path, makedirs

from ...utils.validate_dates import *
from ...utils.validate_hours import validate_hours
from ...utils.get_time_zone import *
from .parse import *
from .MIMS_minute import *
from .MIMS_hour import *
from .AUC_minute import *
from .AUC_hour import *
# from .bafToCSV import *
# from .csvToMIMS import *
# from .baf_to_dataframe import *
from .dataframe_to_MIMS import *
from shutil import copyfile
import warnings

# from SWaN_accel import classify

warnings.filterwarnings("ignore")

area = "data-watch"
logs_watch = "logs-watch"
device = "watch"
file_shortname = "accelerometer"

# since the accelerometer file name is mixed with irregular numbers, file name matching is needed.
name_pattern = "AndroidWearWatch"
TASK = "all"
SAMPLING_RATE = 50.0


def reg_exp_matching(hour_folder_path, name_pattern):
    file_list = listdir(hour_folder_path)
    matched_name = ""
    for file_str in file_list:
        if file_str.startswith(name_pattern):
            matched_name = file_str
            break
    return matched_name


def MIMSExist(hour_folder_path):
    # print(str(hour_folder_path))
    exist = False
    path_mims = None
    # in_path = sorted(glob(os.path.join(hour_folder_path, '020000000000-AccelerationCalibrated.*.sensor.csv')))[0]

    # If the MIMS-unit file already exists, import the csv file for concatenation of daily csv
    # tmpDir = os.path.dirname(in_path)
    path_mims_list = glob(os.path.join(hour_folder_path, "mims*.csv"))
    # print('mims path list')
    # print(path_mims_list)

    if len(path_mims_list) > 0:
        path_mims = path_mims_list[0]
        # print(path_mims + " exists. Skipping csv to MIMS conversion for this file.")
        exist = True

    return exist, path_mims


def HARExist(hour_folder_path):
    # print(str(hour_folder_path))
    exist = False
    path_har = None
    path_har_list = glob(os.path.join(hour_folder_path, "har_*.csv"))
    # print('har path list')
    # print(path_har_list)

    if len(path_har_list) > 0:
        path_har = path_har_list[0]
        # print(path_har + " exists. Skipping csv to HAR conversion for this file.")
        exist = True
    return exist, path_har


def pre_process(microT_root_path, intermediate_file_save_path, p_id, date):
    participant_folder_path = microT_root_path
    area_folder_path = participant_folder_path + sep + area
    hours_with_target_file_list = {}  # included in participant stats report
    if path.exists(area_folder_path):
        date_folder_path = area_folder_path + sep + date
        if path.exists(date_folder_path):
            file_save_date_path = intermediate_file_save_path + sep + "intermediate_file" + sep + p_id + sep + date
            if not path.exists(file_save_date_path):
                makedirs(file_save_date_path)
            day_file_name_mims = device + "_" + file_shortname + "_mims_clean_" + date + ".csv"
            day_file_name_har_intensity = device + "_" + file_shortname + "_har_clean_" + "_intensity_" + date + ".csv"
            day_file_name_har_activity = device + "_" + file_shortname + "_har_clean_" + "_activity_" + date + ".csv"
            day_file_name_har_posture = device + "_" + file_shortname + "_har_clean_" + "_posture_" + date + ".csv"
            day_file_save_path_mims = file_save_date_path + sep + day_file_name_mims
            day_file_save_path_har_intensity = file_save_date_path + sep + day_file_name_har_intensity
            day_file_save_path_har_activity = file_save_date_path + sep + day_file_name_har_activity
            day_file_save_path_har_posture = file_save_date_path + sep + day_file_name_har_posture
            date_swan_file = microT_root_path + sep + area + sep + date + sep + "SWaN_" + date + "_final.csv"
            day_file_name_mims_minute = file_save_date_path + sep + device + "_" + file_shortname + "_mims_minute_" + date + ".csv"
            day_file_name_mims_hour = file_save_date_path + sep + device + "_" + file_shortname + "_mims_hour_" + date + ".csv"
            p_id_no_domain = p_id.split("@")[0]
            swan_dest = file_save_date_path + sep + device + "_" + file_shortname + "_swan_clean_" + date + ".csv"

            day_file_name_auc_minute = file_save_date_path + sep + device + "_" + file_shortname + "_auc_minute_" + date + ".csv"
            day_file_name_auc_hour = file_save_date_path + sep + device + "_" + file_shortname + "_auc_hour_" + date + ".csv"

            # check if swan exists
            if not path.exists(swan_dest):
                if path.exists(date_swan_file):
                    copyfile(date_swan_file, swan_dest)

            mims_dest_exists = True
            if not path.exists(day_file_save_path_mims):
                mims_dest_exists = False

            har_dest_all_exist = True
            if not path.exists(day_file_save_path_har_activity) or \
                    not path.exists(day_file_save_path_har_intensity) or not path.exists(
                day_file_save_path_har_posture):
                har_dest_all_exist = False

            decompose_exits = True
            if not path.exists(day_file_name_mims_minute) or not path.exists(day_file_name_mims_hour):
                decompose_exits = False

            if not mims_dest_exists or not har_dest_all_exist or not decompose_exits:
                # if not path.exists(date_swan_file):
                #     print("For date: " + date)
                #     classify.main(sampling_rate=SAMPLING_RATE, input_folder=microT_root_path,
                #                   file_path=p_id_no_domain, startdateStr=date)
                # print(date_swan_file)

                df_participant_mims = pd.DataFrame()
                df_participant_har_intensity = pd.DataFrame()
                df_participant_har_activity = pd.DataFrame()
                df_participant_har_posture = pd.DataFrame()
                date_folder_path = area_folder_path + sep + date
                # check hourly folder
                validated_hour_list, HAVE_ALL_HOURS = validate_hours(date_folder_path)
                if len(validated_hour_list) == 0:
                    print("Cannot find hour folder in {} data".format(date))
                # iterate through hour folders
                hours_with_target_file = len(validated_hour_list)  # included in participant stats report
                for hour in validated_hour_list:
                    hour_folder_path = date_folder_path + sep + hour
                    # time zone
                    time_zone = get_time_zone(hour_folder_path)
                    # step 2.1: read target hourly file, baf to csv, csv to mims
                    target_file_matched = reg_exp_matching(hour_folder_path, name_pattern)
                    # binary_df = None
                    if len(target_file_matched) > 0:
                        target_file_path = hour_folder_path + sep + target_file_matched
                        # compressed_csv_path = bafToCsv(target_file_path) ## Convert this to a data frame first
                        # binary_df = baf_to_dataframe(target_file_path)
                        # if not mims_dest_exists:
                        mimsExist, mims_path = MIMSExist(hour_folder_path)
                        if mims_path is not None:
                            df_hour_mims = pd.read_csv(mims_path)
                            df_hour_mims = parse_raw_df(df_hour_mims, time_zone)
                            df_participant_mims = pd.concat([df_participant_mims, df_hour_mims])

                        if not har_dest_all_exist:
                            # harExists, har_path = HARExist(hour_folder_path)
                            # out_path_general = hour_folder_path + sep + "har_" + date + "_" + hour + ".csv"
                            out_path_intensity = hour_folder_path + sep + "har_" + "intensity" + ".csv"
                            out_path_posture = hour_folder_path + sep + "har_" + "posture" + ".csv"
                            out_path_activity = hour_folder_path + sep + "har_" + "activity" + ".csv"
                            # run_har = True
                            # if not harExists:
                            #     hr_dfs = mhlab.run_har_on_dataframe(TASK, binary_df, SAMPLING_RATE, out_path_general)
                            #     df_hour_activity = hr_dfs['activity']
                            #     df_hour_intensity = hr_dfs['intensity']
                            #     df_hour_posture = hr_dfs['posture']
                            # else:
                            if path.exists(out_path_activity):
                                df_hour_activity = pd.read_csv(out_path_activity)
                                df_participant_har_activity = pd.concat([df_participant_har_activity, df_hour_activity])
                            if path.exists(out_path_intensity):
                                df_hour_intensity = pd.read_csv(out_path_intensity)
                                df_participant_har_intensity = pd.concat(
                                    [df_participant_har_intensity, df_hour_intensity])
                            if path.exists(out_path_posture):
                                df_hour_posture = pd.read_csv(out_path_posture)
                                df_participant_har_posture = pd.concat([df_participant_har_posture, df_hour_posture])

                    else:
                        hours_with_target_file -= 1
                        continue

                    # step 2.2: parse target hourly file
                    # if df_hour_mims.shape[0] != 0:
                    #     df_hour_mims = parse_raw_df(df_hour_mims, time_zone)
                    #     df_participant_mims = pd.concat([df_participant_mims, df_hour_mims])

                    # if df_hour_activity.shape[0] != 0:
                    #     df_participant_har_activity = pd.concat([df_participant_har_activity, df_hour_activity])

                    # if df_hour_intensity.shape[0] != 0:
                    #     df_participant_har_intensity = pd.concat([df_participant_har_intensity, df_hour_intensity])

                    # if df_hour_posture.shape[0] != 0:
                    #     df_participant_har_posture = pd.concat([df_participant_har_posture, df_hour_posture])

                # Add a module for minute-level mims sample number
                df_participant_mims.reset_index(inplace=True, drop=True)
                df_mims_minute = get_mims_matrix_minute(df_participant_mims)

                hours_with_target_file_list[date] = hours_with_target_file
                if df_participant_mims.shape[0] != 0:
                    df_participant_mims.to_csv(day_file_save_path_mims, index=False)
                if df_participant_har_intensity.shape[0] != 0:
                    df_participant_har_intensity.to_csv(day_file_save_path_har_intensity, index=False)
                if df_participant_har_activity.shape[0] != 0:
                    df_participant_har_activity.to_csv(day_file_save_path_har_activity, index=False)
                if df_participant_har_posture.shape[0] != 0:
                    df_participant_har_posture.to_csv(day_file_save_path_har_posture, index=False)
                if df_mims_minute is not None:
                    df_mims_minute.to_csv(day_file_name_mims_minute, index=False)
                    df_mims_hour = get_mims_matrix_hour(df_mims_minute)
                    df_mims_hour.to_csv(day_file_name_mims_hour, index=False)

            # first_second_pass_output/logs-watch
            auc_dest_exists = True
            if not path.exists(day_file_name_auc_minute) or not path.exists(day_file_name_auc_hour):
                auc_dest_exists = False

            if not auc_dest_exists:
                df_participant_auc = pd.DataFrame()
                date_folder_path = microT_root_path + sep + logs_watch + sep + date
                # check hourly folder
                validated_hour_list, HAVE_ALL_HOURS = validate_hours(date_folder_path)
                if len(validated_hour_list) == 0:
                    print("Cannot find hour folder in {}".format(date_folder_path))
                # iterate through hour folders
                for hour in validated_hour_list:
                    hour_folder_path = date_folder_path + sep + hour
                    # time zone
                    # time_zone = get_time_zone(hour_folder_path)
                    # step 2.1: read target hourly file
                    target_file_matched = list(glob(path.join(hour_folder_path, "Watch-AccelSampling*")))
                    # binary_df = None
                    if len(target_file_matched) > 0:
                        target_file_path = target_file_matched[0]
                        try:
                            df_hour_auc = pd.read_csv(target_file_path, header=None, error_bad_lines=False,
                                                      warn_bad_lines=True)
                            df_participant_auc = pd.concat([df_participant_auc, df_hour_auc])
                        except pd.errors.EmptyDataError:
                            # empty file so skip
                            pass
                        except pd.errors.ParserError as pe:
                            print("ParserError---{} {}".format(target_file_path, pe))

                df_participant_auc.reset_index(inplace=True, drop=True)
                df_auc_minute = get_auc_matrix_minute(df_participant_auc)
                if df_auc_minute is not None:
                    df_auc_minute.to_csv(day_file_name_auc_minute, index=False)
                    df_auc_hour = get_auc_matrix_hour(df_auc_minute)
                    df_auc_hour.to_csv(day_file_name_auc_hour, index=False)


if __name__ == "__main__":
    microT_root_path = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT"
    intermediate_file_save_path = r"C:\Users\jixin\Desktop\temp"
    p_id_list = ["aditya4_internal@timestudy_com"]
    date_start = "2020-01-01"
    date_end = "2020-07-01"

    pre_process(microT_root_path, intermediate_file_save_path, p_id_list, date_start)



from os import sep
import pandas as pd
import warnings

warnings.filterwarnings("ignore")


def parse_raw_df(df_hour_raw):
    columns_names = ["LOG_TIME", "LOG_TYPE", "PARTICIPANT_ID", "FILE_NAME", "NOTES"]
    df_burst_status = pd.DataFrame()
    df_dnd_status = pd.DataFrame()
    if df_hour_raw.shape[0] > 0:
        df_hour_raw.fillna('-1', inplace=True)
        df_burst_status = df_hour_raw
        df_dnd_status = df_hour_raw
        df_hour_raw.columns = columns_names
        df_hour_raw = df_hour_raw[~df_hour_raw["NOTES"].str.contains("Audio_profile")]

        # df_hour_raw['LOG_TIME'] = [x + " " + time_zone for x in df_hour_raw['LOG_TIME']]
        df_hour_raw[['SLEEP_OR_WAKE', 'SLEEP_OR_WAKE_TIME']] = df_hour_raw.NOTES.str.split("|", expand=True)
        df_hour_raw['SLEEP_OR_WAKE'] = df_hour_raw['SLEEP_OR_WAKE'].str.strip()
        df_hour_raw['SLEEP_OR_WAKE_TIME'] = df_hour_raw['SLEEP_OR_WAKE_TIME'].str.lstrip()
        df_hour_raw = df_hour_raw[(df_hour_raw['SLEEP_OR_WAKE'] == 'Current sleep time') |
                                  (df_hour_raw['SLEEP_OR_WAKE'] == 'Next wake time') |
                                  (df_hour_raw['SLEEP_OR_WAKE'] == 'Current wake time')]
        df_hour_raw = df_hour_raw.drop('LOG_TYPE', 1)
        df_hour_raw = df_hour_raw.drop('FILE_NAME', 1)
        df_hour_raw = df_hour_raw.drop('NOTES', 1)
        df_hour_raw = df_hour_raw[['PARTICIPANT_ID', 'LOG_TIME', 'SLEEP_OR_WAKE', 'SLEEP_OR_WAKE_TIME']]

        df_burst_status = df_burst_status[~df_burst_status["NOTES"].str.contains("Audio_profile")]
        df_burst_status[['DAY_TYPE', 'IS_BURST']] = df_burst_status.NOTES.str.split("|", expand=True)
        df_burst_status['DAY_TYPE'] = df_burst_status['DAY_TYPE'].str.strip()
        df_burst_status['IS_BURST'] = df_burst_status['IS_BURST'].str.strip()
        df_burst_status = df_burst_status[(df_burst_status['DAY_TYPE'] == 'BURST mode')]
        # print("No of rows:  " + str(df_burst_status.shape[0]))
        if df_burst_status.shape[0] != 0:
            df_burst_status = df_burst_status.drop('LOG_TYPE', 1)
            df_burst_status = df_burst_status.drop('FILE_NAME', 1)
            df_burst_status = df_burst_status.drop('NOTES', 1)
            df_burst_status = df_burst_status.drop('DAY_TYPE', 1)
            df_burst_status.loc[(df_burst_status.IS_BURST == 'true'), 'IS_BURST_DAY'] = 'True'
            df_burst_status.loc[(df_burst_status.IS_BURST == 'false'), 'IS_BURST_DAY'] = 'False'
            df_burst_status = df_burst_status.drop('IS_BURST', 1)
            df_burst_status = df_burst_status[['PARTICIPANT_ID', 'LOG_TIME', 'IS_BURST_DAY']]

        df_dnd_status = df_dnd_status[~df_dnd_status["NOTES"].str.contains("Audio_profile")]
        df_dnd_status[['DND', 'IS_DND']] = df_dnd_status.NOTES.str.split("|", expand=True)
        df_dnd_status['DND'] = df_dnd_status['DND'].str.strip()
        df_dnd_status['IS_DND'] = df_dnd_status['IS_DND'].str.strip()
        df_dnd_status = df_dnd_status[(df_dnd_status['DND'] == 'DND status')]
        if df_dnd_status.shape[0] != 0:
            df_dnd_status = df_dnd_status.drop('LOG_TYPE', 1)
            df_dnd_status = df_dnd_status.drop('FILE_NAME', 1)
            df_dnd_status = df_dnd_status.drop('NOTES', 1)
            df_dnd_status = df_dnd_status.drop('DND', 1)
            df_dnd_status.loc[(df_dnd_status.IS_DND == '1'), 'IS_IN_DND'] = 'False'
            df_dnd_status.loc[(df_dnd_status.IS_DND != '1'), 'IS_IN_DND'] = 'True'
            df_dnd_status = df_dnd_status.drop('IS_DND', 1)
            df_dnd_status = df_dnd_status[['PARTICIPANT_ID', 'LOG_TIME', 'IS_IN_DND']]
    return df_hour_raw, df_burst_status, df_dnd_status


if __name__ == "__main__":
    target_file = "MicroTUploadManagerServiceNotes.log.csv"
    hour_folder_path = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT\aditya4_internal@timestudy_com\data-watch\2020-06-02\02-EDT"
    target_file_path = hour_folder_path + sep + target_file
    output_file_path = r"C:\Users\jixin\Desktop\temp\temp_file.csv"
    p_id = "aditya4_internal@timestudy_com"

    df_hour_raw = pd.read_csv(target_file_path)
    print(df_hour_raw)
    df_hour_parsed = parse_raw_df(df_hour_raw)
    df_hour_parsed.to_csv(output_file_path, index=False)



import os
import re
import sys

help_text = '''
--------------------------:
Command line help options |
--------------------------:
    * Make sure your current working directory is the root of project folder.

    Usage:
        python preprocessing_all_ema.py <microT_root_path> <intermediate_file_save_path> <participants_included_text_file_path> [date_start] [date_end] <-o>
        python preprocessing_all_ema.py <microT_root_path> <intermediate_file_save_path> <participants_included_text_file_path> [date_start] [date_end]
        python preprocessing_all_ema.py <microT_root_path> <intermediate_file_save_path> <participants_included_text_file_path> [date_start] 
        python preprocessing_all_ema.py <microT_root_path> <intermediate_file_save_path> <participants_included_text_file_path> 
        python preprocessing_all_ema.py [-h]

    Options:
        -o, --hour          Keep hourly file temporarily generated during the pre-process
        -h, --help          Display command line help options
'''


def printHelpOptions():
    print(help_text)


def isPath(path_str):
    isDirectory = os.path.isdir(path_str)
    isFile = os.path.isfile(path_str)
    isPath = isDirectory or isFile
    return isPath


def parse_arguments_ema(argv):
    # usage : python preprocessing_all_ema.py [-h]
    for arg in argv:
        if arg == "-h" or arg == "--help":
            raise SystemExit()

    # check the first four positional arguments
    if len(argv) >= 4:
        allPaths = True
        for i in range(0, 2):
            # allPaths = allPaths and isPath(argv[i])
            allPaths = True
        if allPaths:
            microT_root_path = argv[0]
            intermediate_file_save_path = argv[1]
            # participant_text_file_path = argv[2]
            decrypt_password = argv[2]
            delete_raw = argv[3]
        else:
            print("Error : The first three arguments should be valid paths")
            raise SystemExit()
    else:
        print("Error : Fewer arguments than expected")
        raise SystemExit()

    # usage: with three or more positional arguments
    date_args = [x for x in argv if bool(re.match(r'(\d+\-\d+)', x))]
    # usage : with no date arguments
    if len(date_args) == 0:
        print("Must pass a date argument. Exiting ...")
        sys.exit(1)
    elif len(date_args) == 1:
        date_start = argv[4]
        # date_end = date_start
    elif len(date_args) == 2:
        date_start = argv[4]
        # date_end = date_start
    else:
        print("Error : Wrong number of date arguments")
        raise SystemExit()

    # find if user wants to keep hourly file
    # hourKeep = False
    # for arg in argv:
    #     if arg == "-o" or arg == "--hour":
    #         hourKeep = True

    return microT_root_path, intermediate_file_save_path, decrypt_password, delete_raw, date_start


def parse_arguments_uema(argv):
    # usage : python preprocessing_all_ema.py [-h]
    for arg in argv:
        if arg == "-h" or arg == "--help":
            raise SystemExit()

    # check the first four positional arguments
    if len(argv) >= 4:
        allPaths = True
        for i in range(0, 2):
            allPaths = allPaths and isPath(argv[i])
        if allPaths:
            microT_root_path = argv[0]
            intermediate_file_save_path = argv[1]
            participant_text_file_path = argv[2]
            # decrypt_password = argv[3]
            delete_raw = argv[3]
        else:
            print("Error : The first three arguments should be valid paths")
            raise SystemExit()
    else:
        print("Error : Fewer arguments than expected")
        raise SystemExit()

    # usage: with three or more positional arguments
    date_args = [x for x in argv if bool(re.match(r'(\d+\-\d+)', x))]
    # usage : with no date arguments
    if len(date_args) == 0:
        print("Must pass a date argument. Exiting ...")
        sys.exit(1)
    elif len(date_args) == 1:
        date_start = argv[4]
        # date_end = date_start
    elif len(date_args) == 2:
        date_start = argv[4]
        # date_end = argv[5]
    else:
        print("Error : Wrong number of date arguments")
        raise SystemExit()

    # find if user wants to keep hourly file
    # hourKeep = False
    # for arg in argv:
    #     if arg == "-o" or arg == "--hour":
    #         hourKeep = True

    return microT_root_path, intermediate_file_save_path, participant_text_file_path, delete_raw, date_start


if __name__ == "__main__":
    argv = sys.argv[1:]
    parse_arguments_uema(argv)
    parse_arguments_ema(argv)



import os
import shutil
from os import path, makedirs

from ...utils.validate_dates import *
from ...utils.validate_hours import validate_hours
from ...utils.get_time_zone import *
from .parse import *
import warnings
from shutil import copyfile

warnings.filterwarnings("ignore")

area = "logs"
device = "phone"
file_shortname = "daily_notes"
sleep_wake_notes = "sleep_wake"
burst_notes = "burst_status"
dnd_status = "dnd_status"

name_pattern = "MicroTUploadManagerServiceNotes"


def reg_exp_matching(hour_folder_path, name_pattern):
    file_list = listdir(hour_folder_path)
    matched_name = ""
    for file_str in file_list:
        if file_str.startswith(name_pattern):
            matched_name = file_str
            break
    return matched_name


def pre_process(microT_root_path, intermediate_file_save_path, p_id, decrypt_password, date):
    # copy_report_path = intermediate_file_save_path + sep + "intermediate_file" + sep + p_id
    # if not path.exists(copy_report_path):
    #     makedirs(copy_report_path)
    # p_id_no_domain = p_id.split("@")[0]
    # copied_report_file = copy_report_path + sep + p_id_no_domain + "_daily_report.csv"
    # original_report_file = microT_root_path + sep + p_id + sep + "reports" + sep + "report.csv"
    # if path.exists(original_report_file):
    #     copyfile(original_report_file, copied_report_file)
    # else:
    #     print("No report file found for: " + p_id)

    participant_folder_path = microT_root_path
    area_folder_path = participant_folder_path + sep + area
    hours_with_target_file_list = {}  # included in participant stats report
    if path.exists(area_folder_path):
        date_folder_path = area_folder_path + sep + date
        if path.exists(date_folder_path):
            file_save_date_path = intermediate_file_save_path + sep + "intermediate_file" + sep + p_id + sep + date
            if not path.exists(file_save_date_path):
                makedirs(file_save_date_path)
            day_file_name_sleep_wake = device + "_" + file_shortname + "_" + sleep_wake_notes + "_clean_" + date + ".csv"
            day_file_name_burst_status = device + "_" + file_shortname + "_" + burst_notes + "_clean_" + date + ".csv"
            day_file_name_dnd_status = device + "_" + file_shortname + "_" + dnd_status + "_clean_" + date + ".csv"

            day_file_save_path_sleep_wake = file_save_date_path + sep + day_file_name_sleep_wake
            day_file_save_path_burst = file_save_date_path + sep + day_file_name_burst_status
            day_file_save_path_dnd = file_save_date_path + sep + day_file_name_dnd_status

            if not path.exists(day_file_save_path_dnd) and not path.exists(
                    day_file_save_path_burst) and not path.exists(day_file_save_path_sleep_wake):
                df_pid_sleep_wake = pd.DataFrame()
                df_pid_burst_status = pd.DataFrame()
                df_pid_dnd_status = pd.DataFrame()

                # check hourly folder

                validated_hour_list, HAVE_ALL_HOURS = validate_hours(date_folder_path)

                if len(validated_hour_list) == 0:
                    print("Cannot find hour folder in {} data".format(date))

                # iterate through hour folders

                hours_with_target_file = len(validated_hour_list)  # included in participant stats report
                for hour in validated_hour_list:
                    hour_folder_path = date_folder_path + sep + hour
                    # step 2.1: read target hourly file
                    target_file_matched = reg_exp_matching(hour_folder_path, name_pattern)
                    if len(target_file_matched) > 0:
                        target_file_path = hour_folder_path + sep + target_file_matched
                        try:
                            df_hour_raw = pd.read_csv(target_file_path, header=None)
                        except:
                            # print("Empty csv file", target_file_path)
                            continue
                    else:
                        hours_with_target_file -= 1
                        continue
                    # step 2.2: parse target hourly file

                    if df_hour_raw.shape[0] != 0:
                        df_hour_parsed, df_burst_status, df_dnd_status = parse_raw_df(df_hour_raw)
                        # step 2.4: concatenate hourly file in day level- only if the parsed dataframe is not empty
                        if df_hour_parsed.shape[0] != 0:
                            df_pid_sleep_wake = pd.concat([df_pid_sleep_wake, df_hour_parsed])

                        if df_burst_status.shape[0] != 0:
                            df_pid_burst_status = pd.concat([df_pid_burst_status, df_burst_status])

                        if df_dnd_status.shape[0] != 0:
                            df_pid_dnd_status = pd.concat([df_pid_dnd_status, df_dnd_status])

                hours_with_target_file_list[date] = hours_with_target_file

                if hours_with_target_file != 0:
                    df_pid_sleep_wake.to_csv(day_file_save_path_sleep_wake, index=False)

                    df_pid_burst_status.to_csv(day_file_save_path_burst, index=False)


if __name__ == "__main__":
    microT_root_path = r"C:\Users\jixin\Desktop\testing\logs"
    intermediate_file_save_path = r"C:\Users\jixin\Desktop\testing"
    p_id_list = ["rippingpeprepose@timestudy_com"]
    decrypt_password = ""
    date = "2021-11-17"

    pre_process(microT_root_path, intermediate_file_save_path, p_id, decrypt_password, date)



import os
import shutil
from os import path, makedirs, sep
import pandas as pd
from ...utils.validate_dates import *
from ...utils.validate_hours import validate_hours
from ...utils.get_time_zone import *
# from .parse import *
import warnings

warnings.filterwarnings("ignore")

area = "reports"
device = "phone_watch"
file_shortname = "daily_report"

# since the battery file name is mixed with irregular numbers, file name matching is needed.
name_pattern = "report_"


def reg_exp_matching(hour_folder_path, name_pattern):
    file_list = listdir(hour_folder_path)
    matched_name = ""
    for file_str in file_list:
        if file_str.startswith(name_pattern):
            matched_name = file_str
            break
    return matched_name


def pre_process(microT_root_path, intermediate_file_save_path, p_id, decrypt_password, date):
    participant_folder_path = microT_root_path
    area_folder_path = participant_folder_path + sep + area
    hours_with_target_file_list = {}  # included in participant stats report
    print(area_folder_path)
    if path.exists(area_folder_path):
        date_folder_path = area_folder_path + sep + date
        if path.exists(date_folder_path):
            file_save_date_path = intermediate_file_save_path + sep + "intermediate_file" + sep + p_id + sep + date
            if not path.exists(file_save_date_path):
                makedirs(file_save_date_path)
            day_file_name = device + "_" + file_shortname + "_clean_" + date + ".csv"
            day_file_save_path = file_save_date_path + sep + day_file_name
            src = date_folder_path + sep + name_pattern + date + ".csv"
            dest = day_file_save_path
            print(src)
            if path.exists(src):
                shutil.copy(src, dest)


if __name__ == "__main__":
    microT_root_path = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT"
    intermediate_file_save_path = r"C:\Users\jixin\Desktop\temp"
    p_id_list = ["aditya4_internal@timestudy_com"]
    date_start = "2020-01-01"
    date_end = "2020-07-01"

    pre_process(microT_root_path, intermediate_file_save_path, p_id_list, date_start, date_end)



import pandas as pd
import os
from os import sep
import warnings

warnings.filterwarnings("ignore")


def parse_raw_df(df_hour_raw, p_id):
    if df_hour_raw.shape[0] != 0:
        df_hour_raw.fillna(-1, inplace=True)
        column_names = ['LOG_TIME', 'LOG_TYPE', 'DND', 'DND_VAL']
        df_hour_raw.columns = column_names
        df_hour_raw.insert(0, 'PARTICIPANT_ID', p_id)
        df_hour_raw = df_hour_raw[df_hour_raw['DND'] == 'DND']
        df_hour_raw.loc[(df_hour_raw.DND_VAL == '1'), 'DND_STATUS'] = 'False'
        df_hour_raw.loc[(df_hour_raw.DND_VAL != '1'), 'DND_STATUS'] = 'True'
        df_hour_raw = df_hour_raw.drop('DND_VAL', 1)
        df_hour_raw = df_hour_raw.drop('LOG_TYPE', 1)
    return df_hour_raw


if __name__ == "__main__":
    target_file = "Watch-MiscLogger.log.csv"
    hour_folder_path = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT\aditya4_internal@timestudy_com\logs-watch\2020-05-31\10-EDT"
    target_file_path = hour_folder_path + sep + target_file
    output_file_path = r"C:\Users\jixin\Desktop\temp\temp_file.csv"
    p_id = "aditya4_internal@timestudy_com"

    df_hour_raw = pd.read_csv(target_file_path, header=None)
    df_hour_parsed = parse_raw_df(df_hour_raw, p_id)
    df_hour_parsed.to_csv(output_file_path, index=False)




from os import path, sep
from glob import glob
import pandas as pd


# How this works: search through the intermediate save folder
def generate_output_report(microT_root_path, intermediate_file_save_path, current_date):
    info_list_phone = ["phone_app_usage", "phone_apps_usage_duration", "phone_battery", "phone_daily_notes_burst_status",
                       "phone_daily_notes_dnd_status", "phone_daily_notes_sleep_wake", "phone_detected_activity",
                       "phone_GPS*.csv.zip", "phone_notifications", "phone_system_events", "phone_promptresponse",
                       "phone_stepCount", "phone_wifi_state", "phone_apps_installed"]

    info_list_watch = ["watch_promptresponse", "watch_battery", "watch_accelsampling", "watch_dnd_status",
                       "watch_power_status", "watch_uema_undo_counts", "watch_accelerometer_har_*activity",
                       "watch_accelerometer_har_*intensity", "watch_accelerometer_har_*posture",
                       "watch_accelerometer_mims", "watch_accelerometer_swan"]

    all_info_list = info_list_phone + info_list_watch
    all_columns_list = ["Participant", "Date"] + all_info_list
    # column_num = len(all_info_list)

    root_path_components = microT_root_path.split(sep)
    p_id = root_path_components[len(root_path_components) - 1]

    participant_save_folder_path = intermediate_file_save_path + sep + "intermediate_file" + sep + p_id
    participant_date_folder_path = participant_save_folder_path + sep + current_date

    file_exists_list = [p_id, current_date]

    print(participant_date_folder_path)
    if path.exists(participant_date_folder_path):
        for info in all_info_list:
            filter_list = list(glob(participant_date_folder_path + sep + info + "*"))
            if len(filter_list) == 1:
                file_exists_list.append(True)
            else:
                file_exists_list.append(False)
        summary_df = pd.DataFrame(data=[file_exists_list], columns=all_columns_list)
        summary_df.to_csv(participant_date_folder_path + sep + "intermedaite_output_summary_report.csv", index=False)
        print("Generate output summary file successfully!")

    return




import gzip
import os
import shutil
import subprocess
from os import sep, getcwd
from io import StringIO
import pandas as pd
import datetime
import struct
import warnings

warnings.filterwarnings("ignore")

JAR = getcwd() + sep + "preprocess_scripts" + sep + "utils" + sep + "readBinaryFile.jar"
G_VAL = 9.80

# col = ["Check", "HEADER_TIME_STAMP", "X_ACCELERATION_METERS_PER_SECOND_SQUARED",
#        "Y_ACCELERATION_METERS_PER_SECOND_SQUARED", "Z_ACCELERATION_METERS_PER_SECOND_SQUARED"]

col = ["HEADER_TIME_STAMP", "X_ACCELERATION_METERS_PER_SECOND_SQUARED",
       "Y_ACCELERATION_METERS_PER_SECOND_SQUARED", "Z_ACCELERATION_METERS_PER_SECOND_SQUARED"]


# def baf_to_dataframe(file):
#     print('inside binary to df')
#     print(str(file))
#     tmpDir = os.path.dirname(file)
#     tmpFi = os.path.basename(file)
#     tmpFii = tmpFi.replace("AndroidWearWatch-AccelerationCalibrated-NA.", "")
#     tmpFull = os.path.join(tmpDir, tmpFii)
#
#     tz = os.path.basename(tmpFull).split('-')[-1].split('.')[0]
#     if not tz.startswith('M') and not tz.startswith('P'):
#         print("The last argument in the filename before 'sensor' should contain timeoffset term starting with M or p")
#         return
#
#     try:
#         a = subprocess.Popen(['java', '-jar', JAR, file], stdout=subprocess.PIPE)
#     except:
#         print('Issue with converting baf file to csv - ' + str(tmpFull))
#         return None
#
#     b = StringIO(a.communicate()[0].decode('utf-8'))
#
#     df = pd.read_csv(b, sep=",", names=col)
#     df = df.loc[df['Check'] == "Relevant data"]
#     df.drop(columns=['Check'], inplace=True)
#     return df

def baf_to_dataframe(file):
    tz = os.path.basename(file).split('.')[2].split('-')[-1]

    hourdiff = int(tz[1:3])
    minutediff = int(tz[3:])

    if tz[0] == 'M':
        hourdiff = -int(tz[1:3])
        minutediff = -int(tz[3:])

    in_file = open(file, "rb")
    b = in_file.read(20)
    diction = {}
    i = 0
    while len(b) >= 20:
        t = int.from_bytes(b[0:8], byteorder='big')
        x = struct.unpack('>f', b[8:12])[0]
        y = struct.unpack('>f', b[12:16])[0]
        z = struct.unpack('>f', b[16:20])[0]
        diction[i] = {'time': t, 'x': x, 'y': y, 'z': z}
        i = i + 1

        b = in_file.read(20)

    df = pd.DataFrame.from_dict(diction, "index")
    df.columns = col
    df['HEADER_TIME_STAMP'] = pd.to_datetime(df['HEADER_TIME_STAMP'], unit='ms') + \
                              datetime.timedelta(hours=hourdiff) + datetime.timedelta(minutes=minutediff)
    df['X_ACCELERATION_METERS_PER_SECOND_SQUARED'] = df['X_ACCELERATION_METERS_PER_SECOND_SQUARED']/G_VAL
    df['Y_ACCELERATION_METERS_PER_SECOND_SQUARED'] = df['Y_ACCELERATION_METERS_PER_SECOND_SQUARED']/G_VAL
    df['Z_ACCELERATION_METERS_PER_SECOND_SQUARED'] = df['Z_ACCELERATION_METERS_PER_SECOND_SQUARED']/G_VAL
    return df


if __name__ == "__main__":
    file = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT\aditya4_internal@timestudy_com\data-watch" \
           r"\2020-06-08\10-EDT\AndroidWearWatch-AccelerationCalibrated-NA.020000000000-AccelerationCalibrated.2020" \
           r"-06-08-10-19-57-375-M0400.sensor.baf "
    # outfilePath = r"C:\Users\jixin\Desktop\temp"
    baf_to_dataframe(file)



import os
from os import path, sep, getcwd
import importlib
import time
import shutil

import time_study_preprocessing_main.preprocess_scripts


# participant_text_file_path = getcwd() + sep + "analysis_task" + sep + device + "_participants_included.txt"

def preprocessing_start(microT_root_path, intermediate_file_save_path, delete_raw, date):
    device = 'watch'
    module_name = '.main'
    information_text_file_path = getcwd() + sep + "analysis_task" + sep + device + "_information_included.txt"
    information_list = ["prompt_response", "battery_level", "watch_accel_sampling", "dnd_status", "power_status",
                        "uema_undo_counts", "accelerometer"]
    # information_list = ["battery_level"]
    # parse information and participants text file
    # information_list = preprocess_scripts.utils.parse_information.parse_information(information_text_file_path)
    # p_id_list = []
    # if participant_text_file_path.endswith('.txt'):
    #     p_id_list = preprocess_scripts.utils.parse_participants.parse_participants(participant_text_file_path)
    # else:
    #     p_id_with_domain = participant_text_file_path + '@timestudy_com'
    #     p_id_list.append(p_id_with_domain)
    t0 = time.time()
    # for p_id in p_id_list:
    #     print("Watch pre-processing for: " + str(p_id))
    #     p_id_logs = microT_root_path + sep + p_id + sep + 'logs-watch'
    #     p_id_data = microT_root_path + sep + p_id + sep + 'data-watch'
    p_id_logs = microT_root_path + sep + 'logs-watch'
    p_id_data = microT_root_path + sep + 'data-watch'
    root_path_components = microT_root_path.split(sep)
    p_id = root_path_components[len(root_path_components) - 1]
    if path.exists(p_id_logs):
        # date_list = preprocess_scripts.utils.validate_dates.get_relevant_date_list(p_id_logs, date_start, date_end)
        # for date in date_list:
        # iterate through info
        for info in information_list:
            module_path = "time_study_preprocessing_main.preprocess_scripts." + device + '.' + info
            preprocess_module = importlib.import_module(module_name, module_path)
            # pre-process
            preprocess_module.pre_process(microT_root_path, intermediate_file_save_path, p_id, date)
        if delete_raw == "1":
            p_id_logs_date = p_id_logs + sep + date
            p_id_data_date = p_id_data + sep + date
            if path.exists(p_id_logs_date):
                print("Deleting: " + str(p_id_logs_date))
                shutil.rmtree(p_id_logs_date)
            # if path.exists(p_id_data_date):
            #     shutil.rmtree(p_id_data_date)
    # if delete_raw == "1":
    #     if len(os.listdir(p_id_logs)) == 0:
    #         shutil.rmtree(p_id_logs)
    #     if len(os.listdir(p_id_data)) == 0:
    #         shutil.rmtree(p_id_data)

    t1 = time.time()
    print("Time elapsed is  {} secs : \n".format((t1 - t0)))


def run_uema_main(microT_root_path, intermediate_file_save_path, delete_raw, date_start):
    # try: argv = sys.argv[1:] microT_root_path, intermediate_file_save_path, participant_text_file_path, delete_raw,
    # date_start, date_end, hourKeep = \ preprocess_scripts.utils.parse_cml_argv.parse_arguments_uema( argv) except:
    # preprocess_scripts.utils.parse_cml_argv.printHelpOptions() sys.exit( 'Errors : Incorrect Command Line
    # Arguments. Please correct your arguments according to the references ' 'above.')

    # pre processing
    preprocessing_start(microT_root_path, intermediate_file_save_path, delete_raw, date_start)

# if __name__ == "__main__":
#     # parse arguments try: argv = sys.argv[1:] microT_root_path, intermediate_file_save_path,
#     # participant_text_file_path, delete_raw, date_start, date_end, hourKeep = \
#     # preprocess_scripts.utils.parse_cml_argv.parse_arguments_uema( argv) except:
#     # preprocess_scripts.utils.parse_cml_argv.printHelpOptions() sys.exit( 'Errors : Incorrect Command Line
#     # Arguments. Please correct your arguments according to the references ' 'above.')
#     #
#     # # pre processing
#     # preprocessing_start(microT_root_path, intermediate_file_save_path, participant_text_file_path,
#     #                     delete_raw, date_start, date_end)
#     time_study_preprocessing_main()



def fix_nulls(s):
    for line in s:
        yield line.replace('\0', '')


if __name__ == "__main__":
    area_folder_path = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT\aditya4_internal@timestudy_com\logs-watch"
    date_start = "2020-01-01"
    date_end = "2020-07-01"

    fixed_string = fix_nulls(area_folder_path)



from os import sep
import pandas as pd
from ...utils.convert_timestamp import *
import warnings

warnings.filterwarnings("ignore")


def parse_raw_df(df_hour_raw, time_zone):
    columns_names = ["LOG_TIME", "LIGHT_SENSOR_VALUE", "LIGHT_SENSOR_MAX"]
    if df_hour_raw.shape[0] > 0:
        df_hour_raw.columns = columns_names
        df_hour_raw['LOG_TIME'] = [x + " " + time_zone for x in df_hour_raw['LOG_TIME']]

    return df_hour_raw


if __name__ == "__main__":
    target_file = "Battery.020000000000-Battery.2020-06-02-02-00-25-506-M0400.event.csv"
    hour_folder_path = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT\aditya4_internal@timestudy_com\data-watch\2020-06-02\02-EDT"
    target_file_path = hour_folder_path + sep + target_file
    output_file_path = r"C:\Users\jixin\Desktop\temp\temp_file.csv"
    p_id = "aditya4_internal@timestudy_com"

    df_hour_raw = pd.read_csv(target_file_path)
    print(df_hour_raw)
    df_hour_parsed = parse_raw_df(df_hour_raw)
    df_hour_parsed.to_csv(output_file_path, index=False)



import csv
import os
import shutil
import sys
from os import path, makedirs
from ...utils.validate_dates import *
from ...utils.validate_hours import validate_hours
from .parse import *
from ...utils.fix_nulls import fix_nulls
import warnings

warnings.filterwarnings("ignore")

area = "logs-watch"
device = "watch"
file_shortname = "uema_undo_counts"
target_file = "Watch-PromptActivity.log.csv"


def pre_process(microT_root_path, intermediate_file_save_path, p_id, date):
    participant_folder_path = microT_root_path
    area_folder_path = participant_folder_path + sep + area
    hours_with_target_file_list = {}  # included in participant stats report
    if path.exists(area_folder_path):
        date_folder_path = area_folder_path + sep + date
        if path.exists(date_folder_path):
            file_save_date_path = intermediate_file_save_path + sep + "intermediate_file" + sep + p_id + sep + date
            if not path.exists(file_save_date_path):
                makedirs(file_save_date_path)
            day_file_name = device + "_" + file_shortname + "_clean_" + date + ".csv"
            day_file_save_path = file_save_date_path + sep + day_file_name
            if not path.exists(day_file_save_path):
                df_participant = pd.DataFrame()
                # check hourly folder
                validated_hour_list, HAVE_ALL_HOURS = validate_hours(date_folder_path)
                if len(validated_hour_list) == 0:
                    print("Cannot find hour folder in {} data".format(date))

                # iterate through hour folders
                hours_with_target_file = len(validated_hour_list)  # included in participant stats report
                for hour in validated_hour_list:
                    hour_folder_path = date_folder_path + sep + hour
                    target_file_path = hour_folder_path + sep + target_file

                    # step 2.1: read target hourly file
                    if target_file in listdir(hour_folder_path):
                        rows = []
                        with open(target_file_path) as resp_csv:
                            csv_reader = csv.reader(fix_nulls(resp_csv), delimiter=",")
                            for row in csv_reader:
                                if len(row) == 3:
                                    rows.append(row)
                        df_hour_raw = pd.DataFrame(rows)
                    else:
                        hours_with_target_file -= 1
                        continue

                    # step 2.2: parse target hourly file
                    if df_hour_raw.shape[0] != 0:
                        df_hour_parsed = parse_raw_df(df_hour_raw, p_id)
                        # step 2.4: concatenate hourly file in day level
                        if df_hour_parsed.shape[0] != 0:
                            df_participant = pd.concat([df_participant, df_hour_parsed])

                hours_with_target_file_list[date] = hours_with_target_file
                if hours_with_target_file != 0:
                    df_participant.to_csv(day_file_save_path, index=False)


if __name__ == "__main__":
    microT_root_path = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT"
    intermediate_file_save_path = r"C:\Users\jixin\Desktop\temp"
    p_id_list = ["aditya4_internal@timestudy_com"]
    date_start = "2020-01-01"
    date_end = "2020-07-01"
    hourKeep = True

    pre_process(microT_root_path, intermediate_file_save_path, p_id_list, date_start)



from os import sep
import pandas as pd
import numpy as np
import warnings

# warnings.filterwarnings("ignore")
NAN = np.nan
colnames = ["YEAR_MONTH_DAY", "HOUR", "MINUTE", "TIMEZONE", "SAMPLE_COUNT",	"AUC_X", "AUC_Y", "AUC_Z"]

from datetime import datetime, timedelta
import pandas as pd

time_offset_dict = {
    "CDT": "UTC-05",
    "CST": "UTC-06",
    "MDT": "UTC-06",
    "MST": "UTC-07",
    "PDT": "UTC-07",
    "PST": "UTC-08",
    "EDT": "UTC-04",
    "EST": "UTC-05",
    "AKDT": "UTC-08",
    "AKST": "UTC-09",
    "HDT": "UTC-09",
    "HST": "UTC-10"
}


def parse_time_offset(time_offset):
    sign_str = time_offset.strip('UTC')[0]
    if sign_str == "-":
        sign = -1
    elif sign_str == "+":
        sign = 1
    else:
        sigh = 0

    time_offset_int = int(time_offset.strip('UTC')[1:])
    time_delta = timedelta(hours=time_offset_int)

    return time_delta, sign


def get_time_offset(time_zone_abbr):
    time_delta = timedelta(hours=0)
    sign = 0

    if time_zone_abbr in time_offset_dict:
        time_offset = time_offset_dict[time_zone_abbr]
        time_delta, sign = parse_time_offset(time_offset)

    return time_delta, sign


def convert_timestamp_int_list_to_readable_time(timestamp_int_list, time_zone):
    time_delta, sign = get_time_offset(time_zone)
    if time_zone == "unknownTZ" or sign == 0:
        readable_time_str = ["unknown time zone"] * len(timestamp_int_list)
    else:
        timestamp_naive_list = pd.to_datetime(timestamp_int_list, unit='ms', errors='coerce')
        timestamp_TZaware_list = timestamp_naive_list + sign * time_delta
        converter = lambda x: x.strftime("%Y-%m-%d %H:%M:%S.%f")[:-3] if pd.notnull(x) else ''
        readable_time_str = pd.Series(map(converter, timestamp_TZaware_list))
        readable_time_str += " " + time_zone

    return readable_time_str


def get_auc_matrix_minute(df_auc_day):
    if df_auc_day.shape[0] == 0:
        return None

    # transform df_mims_day
    ymd_list = []
    hour_list = []
    minute_list = []
    tz_list = []


    for time_str in df_auc_day[0]:
        time_str_components = time_str.split(" ")
        if len(time_str_components) > 5:
            ymd_list.append("-".join([time_str_components[5], time_str_components[1], time_str_components[2]]))
            tz_list.append(time_str_components[4])
        else:
            ymd_list.append("")
            tz_list.append("")


    # skip for days with multiple timezone
    tz_list = [x for x in tz_list if len(x) > 0]
    tz_set = set(tz_list)
    tz_set_clean = set([x.split("_")[0] for x in tz_set])
    tz_num = len(tz_set_clean)

    datetime_list = convert_timestamp_int_list_to_readable_time(df_auc_day[2], list(tz_set_clean)[0])
    # print(datetime_list)
    for ts in datetime_list:
        time_str_components = ts.split(" ")[1].split(":")
        if len(ts.split(" ")) == 3:
            try:
                hour_list.append(int(time_str_components[0]))
            except ValueError as ee:
                print("valueError===={}".format(time_str_components))
                raise ee
            minute_list.append(int(time_str_components[1]))
        else:
            hour_list.append(NAN)
            minute_list.append(NAN)

    df_auc_day.loc[:, "Hour"] = hour_list
    df_auc_day.loc[:, "Minute"] = minute_list
    df_auc_day.loc[:, "Date"] = ymd_list

    ymd_list = [x for x in ymd_list if len(x) > 0]
    YMD = list(set(ymd_list))[0]

    df_auc_day = df_auc_day[df_auc_day.Date == YMD]
    df_auc_day.reset_index(inplace=True, drop=True)

    # iterate through all minutes in a day and find matched time in df_mims_day
    hour_min_dict = dict()
    for hour in range(24):
        for min in range(60):
            hour_min = str(hour) + "_" + str(min)

            # temporary measure for days with multiple timezones
            if tz_num > 1:
                hour_min_dict[hour_min] = {"SAMPLE_COUNT": NAN, "AUC_X": NAN, "AUC_Y": NAN, "AUC_Z": NAN}
                continue

            df_auc_hour = df_auc_day[df_auc_day.Hour == hour]
            df_auc_min = df_auc_hour[df_auc_hour.Minute == min]
            if len(df_auc_min) > 0:
                hour_min_dict[hour_min] = dict()
                hour_min_dict[hour_min]["SAMPLE_COUNT"] = df_auc_min[3].sum()
                hour_min_dict[hour_min]["AUC_X"] = df_auc_min[4].sum()
                hour_min_dict[hour_min]["AUC_Y"] = df_auc_min[5].sum()
                hour_min_dict[hour_min]["AUC_Z"] = df_auc_min[6].sum()
            else:
                hour_min_dict[hour_min] = {"SAMPLE_COUNT": 0, "AUC_X": NAN, "AUC_Y": NAN, "AUC_Z": NAN}


    tz = list(tz_set_clean)[0]
    rows = []
    for hour_min in hour_min_dict:
        row = [YMD, hour_min.split("_")[0], hour_min.split("_")[1], tz, hour_min_dict[hour_min]["SAMPLE_COUNT"],
               hour_min_dict[hour_min]["AUC_X"], hour_min_dict[hour_min]["AUC_Y"], hour_min_dict[hour_min]["AUC_Z"]]
        rows.append(row)

    df_minute = pd.DataFrame(rows, columns=colnames)

    return df_minute


if __name__ == "__main__":
    df_mims_day = pd.read_csv(
        r"D:\data\TIME\raw\logs-watch\2021-08-26\06-EDT\Watch-AccelSampling.log.csv", header=None)
    # print(df_mims_day)
    df_minute = get_auc_matrix_minute(df_mims_day)
    df_minute.to_csv(r"C:\Users\Jixin\Downloads\auc_minute.csv")
    print(df_minute[df_minute.HOUR == "6"])



import os
from glob import glob

folder_list = ["data", "data-watch", "logs", "logs-watch"]


# def get_time_zone(date_folder_path):
#     time_zone = "unknownTZ"
#
#     if os.path.exists(date_folder_path):
#         hour_list = glob(os.path.join(date_folder_path, '*-*'))
#         for hour_path in hour_list:
#             time_zone = hour_path.split('-')[-1]
#             return time_zone
#
#     return time_zone

def get_time_zone(hour_folder_path):
    time_zone = "unknownTZ"

    if os.path.exists(hour_folder_path):
        time_zone = hour_folder_path.split('-')[-1]

    return time_zone


if __name__ == "__main__":
    p_id = "aditya4_internal@timestudy_com"
    date_folder_path = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT\aditya4_internal@timestudy_com\data\2020-06-03"
    print("{} is located in time zone {} .".format(p_id, get_time_zone(date_folder_path)))



from os import listdir
import re
from datetime import datetime, timedelta


def findExistedDateFolder(dates_list):
    existed_folder_list = [x for x in dates_list if bool(re.match(r'(\d+\-\d+\-\d+)', x))]
    return existed_folder_list


def filterDates(dates_list, date_start, date_end):
    dates_to_check = []
    date_format = '%Y-%m-%d'

    date_start_entered = datetime.strptime(date_start, date_format)
    date_end_entered = datetime.strptime(date_end, date_format)

    dt_dates = [datetime.strptime(date, date_format) for date in dates_list]
    dt_dates_sorted = sorted(dt_dates)

    for date in dt_dates_sorted:
        if (date >= date_start_entered) and (date <= date_end_entered):
            dates_to_check.append(date.strftime(date_format))

    return dates_to_check


def validate_dates(area_folder_path, date_start, date_end):
    dates_list = listdir(area_folder_path)
    if len(dates_list) == 0:
        return []

    dates_list_existed = findExistedDateFolder(dates_list)
    if len(dates_list_existed) == 0:
        return []

    dates_list_filtered = filterDates(dates_list_existed, date_start, date_end)
    if len(dates_list_filtered) > 0:
        validated_start_date = dates_list_filtered[0]
        validated_end_date = dates_list_filtered[-1]
    else:
        validated_start_date = "None"
        validated_end_date = "None"

    print("Entered Start Date (inclusive) :  {}   ,   Entered End Date (inclusive) :  {}".format(date_start, date_end))
    print("Validated Start Date (inclusive) :  {}   ,   Validated End Date (inclusive) :  {}".format(
        validated_start_date,
        validated_end_date))

    return dates_list_filtered


def get_relevant_date_list(folder_path, date_start, date_end):
    dates_list = listdir(folder_path)
    date_format = '%Y-%m-%d'
    date_start = datetime.strptime(date_start, date_format)
    date_end = datetime.strptime(date_end, date_format)
    if len(dates_list) == 0:
        return []
    dates_list_existed = findExistedDateFolder(dates_list)
    if len(dates_list_existed) == 0:
        return []
    formatted_dates = []
    for date in dates_list_existed:
        date = datetime.strptime(date, date_format)
        formatted_dates.append(date)
    min_date = min(formatted_dates)
    max_date = max(formatted_dates)
    if date_start <= min_date:
        date_start = min_date
    if date_end >= max_date:
        date_end = max_date
    final_dates = []
    date_increment = date_start
    while date_increment <= date_end:
        date_to_add = date_increment.strftime(date_format)
        final_dates.append(date_to_add)
        date_increment += timedelta(days=1)
    return final_dates


if __name__ == "__main__":
    area_folder_path = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT\aditya4_internal@timestudy_com\logs-watch"
    date_start = "2020-01-01"
    date_end = "2020-07-01"

    validated_date_list = validate_dates(area_folder_path, date_start, date_end)
    print("Total number of valid date folders  :  {}".format(len(validated_date_list)))
    print(validated_date_list)



import csv
import sys
import os
from glob import glob
import pandas as pd
from os import sep, path

# Import the rpy2 package to run R commands and then import MIMSunit package using that
from rpy2.robjects.packages import importr
from rpy2.robjects import pandas2ri
from rpy2.robjects.conversion import localconverter
import rpy2.robjects as ro
from rpy2.robjects import FloatVector
import warnings

warnings.filterwarnings("ignore")

mims_unit = importr('MIMSunit')
feather_r = importr('arrow')
get_mims = mims_unit.mims_unit

G_VAL = 9.8
DYNAMIC_RANGE = [-8, 8]


def dataframe_to_MIMS(hour_folder_path, date, hour, df):
    in_path = hour_folder_path
    out_har_path = hour_folder_path + sep + "har_" + date + "_" + hour + ".csv"

    raw_data_csv = df

    # Convert to R dataframe needed for MIMSunit
    feather_path = hour_folder_path + sep + 'temp_feather.feather'
    print("Feather file at: " + feather_path)
    raw_data_csv.to_feather(feather_path)
    if path.exists(feather_path):
        r_from_pd_df = feather_r.read_feather(feather_path)
    if path.exists(feather_path):
        os.remove(feather_path)
    # with localconverter(ro.default_converter + pandas2ri.converter):
    #     r_from_pd_df = ro.conversion.py2rpy(raw_data_csv)
    # Convert dynamic range into R list
    r_g_range = FloatVector(DYNAMIC_RANGE)
    mims_df = get_mims(r_from_pd_df, dynamic_range=r_g_range, epoch='1 sec')
    with localconverter(ro.default_converter + pandas2ri.converter):
        pd_from_r_df = ro.conversion.rpy2py(mims_df)

    pd_from_r_df['HEADER_TIME_STAMP'] = pd_from_r_df['HEADER_TIME_STAMP'].dt.strftime('%Y-%m-%d %H:%M:%S')
    out_path = in_path + sep + "mims_" + date + "_" + hour + ".csv"
    pd_from_r_df.to_csv(out_path, index=False)
    return pd_from_r_df


if __name__ == "__main__":
    in_path = sys.argv[1]
    dataframe_to_MIMS(in_path)



from datetime import datetime, timedelta
import pandas as pd

time_offset_dict = {
    "CDT": "UTC-05",
    "CST": "UTC-06",
    "MDT": "UTC-06",
    "MST": "UTC-07",
    "PDT": "UTC-07",
    "PST": "UTC-08",
    "EDT": "UTC-04",
    "EST": "UTC-05",
    "AKDT": "UTC-08",
    "AKST": "UTC-09",
    "HDT": "UTC-09",
    "HST": "UTC-10"
}


def parse_time_offset(time_offset):
    sign_str = time_offset.strip('UTC')[0]
    if sign_str == "-":
        sign = -1
    elif sign_str == "+":
        sign = 1
    else:
        sigh = 0

    time_offset_int = int(time_offset.strip('UTC')[1:])
    time_delta = timedelta(hours=time_offset_int)

    return time_delta, sign


def get_time_offset(time_zone_abbr):
    time_delta = timedelta(hours=0)
    sign = 0

    if time_zone_abbr in time_offset_dict:
        time_offset = time_offset_dict[time_zone_abbr]
        time_delta, sign = parse_time_offset(time_offset)

    return time_delta, sign


def convert_timestamp_int_list_to_readable_time(timestamp_int_list, time_zone):
    time_delta, sign = get_time_offset(time_zone)
    if time_zone == "unknownTZ" or sign == 0:
        readable_time_str = ["unknown time zone"] * len(timestamp_int_list)
    else:
        timestamp_naive_list = pd.to_datetime(timestamp_int_list, unit='ms', errors='coerce')
        timestamp_TZaware_list = timestamp_naive_list + sign * time_delta
        converter = lambda x: x.strftime("%Y-%m-%d %H:%M:%S.%f")[:-3] if pd.notnull(x) else ''
        readable_time_str = pd.Series(map(converter, timestamp_TZaware_list))
        readable_time_str += " " + time_zone

    return readable_time_str


if __name__ == "__main__":
    sample_csv_path = r"E:\intermediate_file\aditya4_internal@timestudy_com\2020-06-03\phone_app_usage_clean_hour_temp\phone_app_usage_clean_03-EDT.csv"
    time_zone = "EDT"
    df = pd.read_csv(sample_csv_path)
    print(convert_timestamp_int_list_to_readable_time(df['LAST_HOUR_TIMESTAMP'], time_zone))
    # print("{} is translated to {} .".format(str(timestamp_int), convert_timestamp2string(timestamp_int, time_zone)))



import os
import shutil
from os import path, makedirs

from ...utils.validate_dates import *
from ...utils.validate_hours import validate_hours
from .parse import *
import warnings
# import zipFile
import pyminizip

warnings.filterwarnings("ignore")

area = "data"
device = "phone"
file_shortname = "location_clustering_json"

# since the battery file name is mixed with irregular numbers, file name matching is needed.
name_pattern = "lsf.json"


def reg_exp_matching(hour_folder_path, name_pattern):
    file_list = listdir(hour_folder_path)
    matched_name = ""
    for file_str in file_list:
        if file_str.startswith(name_pattern):
            matched_name = file_str
            break
    return matched_name


def pre_process(microT_root_path, intermediate_file_save_path, p_id, decrypt_password, date):
    participant_folder_path = microT_root_path
    area_folder_path = participant_folder_path + sep + area

    # step 2: iterate through all hour folders for each date
    if path.exists(area_folder_path):
        date_folder_path = area_folder_path + sep + date
        if path.exists(date_folder_path):
            file_save_date_path = intermediate_file_save_path + sep + "intermediate_file" + sep + p_id + sep + date
            if not path.exists(file_save_date_path):
                makedirs(file_save_date_path)

            # check hourly folder
            validated_hour_list, HAVE_ALL_HOURS = validate_hours(date_folder_path)
            if len(validated_hour_list) == 0:
                print("Cannot find hour folders in {} data".format(date))
            # iterate through hour folders
            for hour in validated_hour_list:
                hour_folder_path = date_folder_path + sep + hour

                if not path.exists(hour_folder_path):
                    continue
                # step 2.1: read target hourly file
                target_file_matched = reg_exp_matching(hour_folder_path, name_pattern)

                if len(target_file_matched) > 0:
                    target_file_path = hour_folder_path + sep + target_file_matched
                    day_file_name = device + "_" + file_shortname + "_" + date + "_" + hour + ".json"
                    day_file_save_path = file_save_date_path + sep + day_file_name
                    day_zip_file_save_path = day_file_save_path + '.zip'
                    try:
                        pyminizip.compress(target_file_path, None, day_zip_file_save_path, decrypt_password, 0)
                    except:
                        # print("Empty csv file", target_file_path)
                        continue
                else:
                    continue


if __name__ == "__main__":
    microT_root_path = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT"
    intermediate_file_save_path = r"C:\Users\jixin\Desktop\temp"
    p_id_list = ["aditya4_internal@timestudy_com"]
    date_start = "2020-01-01"
    date_end = "2020-07-01"

    pre_process(microT_root_path, intermediate_file_save_path, p_id_list, date_start, date_end)



def filterInformationList(information_list):

    # remove duplicates
    filtered_list = list(dict.fromkeys(information_list))
    return filtered_list

def cleanLine(line):
    line = line.strip('\n')
    return line


def parse_information(information_text_file_path):
    information_list = []
    with open(information_text_file_path) as fp:
        Lines = fp.readlines()
        for line in Lines:
            cleaned_line = cleanLine(line)
            if len(cleaned_line) != 0:
                information_list.append(cleaned_line)

    information_list_filtered = filterInformationList(information_list)
    print("\n> Entered information items ({} items in total) :".format(len(information_list_filtered)))
    for i in range(len(information_list_filtered)):
        print(" {}.  {}".format(i + 1, information_list_filtered[i]))
    print("\n")
    return information_list_filtered


if __name__ == "__main__":
    information_text_file_path = r"C:\Users\jixin\Documents\GitHub\microt_preprocessing\sample_file\watch_information_sample"
    information_list = parse_information(information_text_file_path)




import sys
import os
from os import path, sep, getcwd
import importlib
import time
import shutil
import time_study_preprocessing_main.preprocess_scripts
import time_study_preprocessing_main.preprocessing_all_uema
from time_study_preprocessing_main.preprocessing_all_uema import run_uema_main


def preprocessing_start(microT_root_path, intermediate_file_save_path, decrypt_password,
                        delete_raw, date):
    device = 'phone'
    module_name = '.main'
    # information_text_file_path = getcwd() + sep + "analysis_task" + sep + device + "_information_included.txt"
    information_list = ["app_usage", "app_use_duration", "battery", "daily_notes", "detected_activity", "GPS",
                        "notif_logs", "phone_broadcasts", "prompt_response", "step_count", "wifi_state",
                        "apps_installed", "daily_report", "ringer_mode", "location_cluster_json"]
    # information_list = []
    # parse information and participants text file
    # information_list = preprocess_scripts.utils.parse_information.parse_information(information_text_file_path)
    p_id_list = []
    # first check if participant list string ends with .txt. If it is .txt use the code below or else just add that
    # to the list
    # if participant_text_file_path.endswith('.txt'):
    #     p_id_list = preprocess_scripts.utils.parse_participants.parse_participants(participant_text_file_path)
    # else:
    #     p_id_with_domain = participant_text_file_path + '@timestudy_com'
    #     p_id_list.append(p_id_with_domain)

    t0 = time.time()
    # for p_id in p_id_list:
    # print("Phone pre-processing for: " + str(p_id))
    # iterate through participants
    # p_id_logs = microT_root_path + sep + p_id + sep + 'logs'
    # p_id_data = microT_root_path + sep + p_id + sep + 'data'
    p_id_logs = microT_root_path + sep + 'logs'
    p_id_data = microT_root_path + sep + 'data'
    root_path_components = microT_root_path.split(sep)
    p_id = root_path_components[len(root_path_components) - 1]

    if path.exists(p_id_logs):
        # date_list = preprocess_scripts.utils.validate_dates.get_relevant_date_list(p_id_logs, date_start, date_end)
        # for date in date_list:
        for info in information_list:
            module_path = "time_study_preprocessing_main.preprocess_scripts." + device + '.' + info
            preprocess_module = importlib.import_module(module_name, module_path)
            # pre-process
            preprocess_module.pre_process(microT_root_path, intermediate_file_save_path, p_id, decrypt_password,
                                          date)
        if delete_raw == "1":
            p_id_logs_date = p_id_logs + sep + date
            p_id_data_date = p_id_data + sep + date
            if path.exists(p_id_logs_date):
                print("Deleting: " + str(p_id_logs_date))
                try:
                    shutil.rmtree(p_id_logs_date)
                except PermissionError:
                    print("PermissionError when trying to delete raw data ")
            if path.exists(p_id_data_date):
                print("Deleting: " + str(p_id_data_date))
                try:
                    shutil.rmtree(p_id_data_date)
                except PermissionError:
                    print("PermissionError when trying to delete raw data ")

    t1 = time.time()
    print("Time elapsed is  {} secs : \n".format((t1 - t0)))


def run_ema_main(microT_root_path, intermediate_file_save_path, decrypt_password, delete_raw, date):
    p_id = microT_root_path.split(sep)[-1]

    # try:
    preprocessing_start(microT_root_path, intermediate_file_save_path, decrypt_password,
                        delete_raw, date)
    # except:
    #     preprocess_scripts.utils.parse_cml_argv.printHelpOptions()
    #     sys.exit(
    #         'Errors : Incorrect Command Line Arguments. Please correct your arguments according to the references '
    #         'above.')

    # watch preprocessing
    run_uema_main(microT_root_path, intermediate_file_save_path, delete_raw, date)

    # output summary report
    # if date_start == date_end:
    time_study_preprocessing_main.preprocess_scripts.utils.output_summary_report.generate_output_report(microT_root_path, intermediate_file_save_path,
                                                                          date)

    print("=========== {}, {} finished ===========".format(p_id, date))


if __name__ == "__main__":
    # parse arguments
    try:
        argv = sys.argv[1:]
        microT_root_path, intermediate_file_save_path, decrypt_password, delete_raw, date_start = \
            preprocess_scripts.utils.parse_cml_argv.parse_arguments_ema(argv)
    except:
        preprocess_scripts.utils.parse_cml_argv.printHelpOptions()
        sys.exit(
            'Errors : Incorrect Command Line Arguments. Please correct your arguments according to the references '
            'above.')

    # # pre processing
    # preprocessing_start(microT_root_path, intermediate_file_save_path, decrypt_password,
    #                     delete_raw, date_start, date_end)
    # # python_version = str(sys.version_info.major) + "." + str(sys.version_info.minor) os.system( 'python' +
    # # python_version + ' preprocessing_all_uema.py ' + microT_root_path + " " + intermediate_file_save_path + " " +
    # # participant_text_file_path + " " + delete_raw + " " + date_start + " " + date_end)
    #
    # # watch preprocessing
    # run_uema_main(microT_root_path, intermediate_file_save_path, delete_raw, date_start, date_end)
    #
    # # output summary report # if date_start == date_end:
    # preprocess_scripts.utils.output_summary_report.generate_output_report(microT_root_path,
    # intermediate_file_save_path, date_start)

    run_ema_main(microT_root_path, intermediate_file_save_path, decrypt_password, delete_raw, date_start)



from os import sep
import pandas as pd
import warnings

warnings.filterwarnings("ignore")


def parse_raw_df(df_hour_raw, p_id):
    column_names = ['Participant_ID', 'Prompt_Type', 'Study_Mode', 'Prompt_Trigger', 'Time_Window_Start',
                    'Time_Window_End', 'Initial_Prompt_Date', 'Initial_Prompt_Local_Time', 'Initial_Prompt_UTC_Offset ',
                    'Initial_Prompt_UnixTime',
                    'Answer_Status',
                    'Reprompt1_Prompt_Date',
                    'Reprompt1_Prompt_Local_Time',
                    'Reprompt1_Prompt_UnixTime',
                    'Reprompt2_Prompt_Date',
                    'Reprompt2_Prompt_Local_Time',
                    'Reprompt2_Prompt_UnixTime ',
                    'Reprompt3_Prompt_Date',
                    'Reprompt3_Prompt_Local_Time',
                    'Reprompt3_Prompt_UnixTime',
                    'Reprompt4_Prompt_Date',
                    'Reprompt4_Prompt_Local_Time',
                    'Reprompt4_Prompt_UnixTime',
                    'Reprompt5_Prompt_Date',
                    'Reprompt5_Prompt_Local_Time',
                    'Reprompt5_Prompt_UnixTime',
                    'Question_Set_Completion_Date',
                    'Question_Set_Completion_Local_Time',
                    'Question_Set_Completion_UnixTime',
                    'Question_Set_Completion_Prompt_Number',
                    'Probabilistic_Question_Set_Selected',
                    'Number_Of_Questions_Presented',
                    'Survey version number',
                    'Question_1_ID'
                    # 'Question_X_Text',
                    # 'Question_X_Answer_Text ',
                    # 'Question_X_Answer_Unixtime'
                    ]
    # name the first 33 columns
    column_indices = range(len(column_names))
    new_names = column_names
    old_names = df_hour_raw.columns[column_indices]
    df_hour_raw.rename(columns=dict(zip(old_names, new_names)), inplace=True)

    # name the rest of the columns
    column_indices_questions = range(33, df_hour_raw.shape[1])
    new_names = []
    for qNum in range(1, int((df_hour_raw.shape[1] - 33) / 4) + 1):
        new_name_per_question = [x.replace("X", str(qNum)) for x in
                                 ['Question_X_ID', 'Question_X_Text', 'Question_X_Answer_Text ',
                                  'Question_X_Answer_Unixtime']]
        new_names += new_name_per_question
    old_names = df_hour_raw.columns[column_indices_questions]
    df_hour_raw.rename(columns=dict(zip(old_names, new_names)), inplace=True)

    return df_hour_raw


if __name__ == "__main__":
    target_file = "PromptResponses.log.csv"
    hour_folder_path = r"E:\data\wocket\Wockets-win32-x64\resources\app\src\srv\MICROT\stephen2_internal@timestudy_com\logs\2020-05-06\21-EDT"
    target_file_path = hour_folder_path + sep + target_file
    output_file_path = r"C:\Users\jixin\Desktop\temp\temp_file.csv"
    p_id = "stephen2_internal@timestudy_com"

    df_hour_raw = pd.read_csv(target_file_path, header=None)
    # print(df_hour_raw)
    df_hour_parsed = parse_raw_df(df_hour_raw, p_id)
    df_hour_parsed.to_csv(output_file_path, index=False)



from . import parse_information
from . import parse_participants
from . import validate_dates
from . import validate_hours
from . import get_time_zone
from . import parse_cml_argv
from . import fix_nulls
from .import output_summary_report
